@@ -1,5 +1,5 @@
 #!/usr/bin/python2
-# Copyright (c) 2003-2016 CORE Security Technologies
+# SECUREAUTH LABS. Copyright 2018 SecureAuth Corporation. All rights reserved.
 #
 # This software is provided under under a slightly modified version
 # of the Apache Software License. See the accompanying LICENSE file
@@ -29,10 +29,10 @@ import sys
 
 from impacket import ImpactDecoder, ImpactPacket, IP6, ICMP6, version
 
-print version.BANNER
+print(version.BANNER)
 
 if len(sys.argv) < 3:
-	print "Use: %s <src ip> <dst ip>" % sys.argv[0]
+	print("Use: %s <src ip> <dst ip>" % sys.argv[0])
 	sys.exit(1)
 
 src = sys.argv[1]
@@ -52,7 +52,7 @@ s = socket.socket(socket.AF_INET6, socket.SOCK_RAW, socket.IPPROTO_ICMPV6)
 
 payload = "A"*156
 
-print "PING %s %d data bytes" % (dst, len(payload))
+print("PING %s %d data bytes" % (dst, len(payload)))
 seq_id = 0
 while 1:
 	# Give the ICMP packet the next ID in the sequence.
@@ -77,6 +77,6 @@ while 1:
 
 	   # If the packet matches, report it to the user.
 	   if ICMP6.ICMP6.ECHO_REPLY == rip.get_type():
-		   print "%d bytes from %s: icmp_seq=%d " % (rip.child().get_size()-4,dst,rip.get_echo_sequence_number())
+		   print("%d bytes from %s: icmp_seq=%d " % (rip.child().get_size()-4,dst,rip.get_echo_sequence_number()))
 
 	   time.sleep(1)
