@@ -1,4 +1,4 @@
-# Copyright (c) 2003-2016 CORE Security Technologies
+# SECUREAUTH LABS. Copyright 2018 SecureAuth Corporation. All rights reserved.
 #
 # This software is provided under under a slightly modified version
 # of the Apache Software License. See the accompanying LICENSE file
@@ -591,33 +591,13 @@ class Dot11WEPDecoder(BaseDot11Decoder):
         
         return wep
 
-    def decrypt_data(self, key_string):
-        'Return \'WEP Data\' decrypted'
-        
-        # Needs to be at least 8 bytes of payload 
-        if len(self.body_string)<8:
-            return self.body_string
-        
-        # initialize the first bytes of the key from the IV 
-        # and copy rest of the WEP key (the secret part) 
-        key=self.get_iv()+key_string
-        rc4=RC4(key)
-        out=rc4.decrypt(data)
-        dwd=Dot11WEPData(out)
-        
-        if False: # is ICV correct
-            return dwd
-        else:
-            return self.body_string
-
-
 class Dot11WEPDataDecoder(BaseDot11Decoder):
     def __init__(self):
         BaseDot11Decoder.__init__(self)
-        
+
     def decode(self, aBuffer):
         wep_data = dot11.Dot11WEPData(aBuffer)
-        
+
         if not wep_data.check_icv():
             # TODO: Do something when the icv is not correct
             pass
@@ -626,65 +606,65 @@ class Dot11WEPDataDecoder(BaseDot11Decoder):
 
         llc_decoder = LLCDecoder()
         packet = llc_decoder.decode(wep_data.body_string)
-        
+
         wep_data.contains(packet)
-        
+
         return wep_data
 
 
 class Dot11WPADecoder(BaseDot11Decoder):
     def __init__(self):
         BaseDot11Decoder.__init__(self)
-        
+
     def decode(self, aBuffer, key=None):
         wpa = dot11.Dot11WPA(aBuffer)
         self.set_decoded_protocol( wpa )
 
         if wpa.is_WPA() is False:
             return None
-        
+
         if key:
             decoded_string=wpa.get_decrypted_data()
-            
-            wpa_data = Dot11DataWPADataDecoder()
+
+            wpa_data = Dot11WPADataDecoder()
             packet = wpa_data.decode(decoded_string)
         else:
             data_decoder = DataDecoder()
             packet = data_decoder.decode(wpa.body_string)
-        
+
         wpa.contains(packet)
-        
+
         return wpa
-    
+
 class Dot11WPADataDecoder(BaseDot11Decoder):
     def __init__(self):
         BaseDot11Decoder.__init__(self)
-        
+
     def decode(self, aBuffer):
         wpa_data = dot11.Dot11WPAData(aBuffer)
         self.set_decoded_protocol( wpa_data )
 
         llc_decoder = LLCDecoder()
         packet = self.llc_decoder.decode(wpa_data.body_string)
-        
+
         wpa_data.contains(packet)
-        
+
         return wpa_data
 
 class Dot11WPA2Decoder(BaseDot11Decoder):
     def __init__(self):
         BaseDot11Decoder.__init__(self)
-        
+
     def decode(self, aBuffer, key=None):
         wpa2 = dot11.Dot11WPA2(aBuffer)
         self.set_decoded_protocol( wpa2 )
 
         if wpa2.is_WPA2() is False:
             return None
-        
+
         if key:
             decoded_string=wpa2.get_decrypted_data()
-            
+
             wpa2_data = Dot11WPA2DataDecoder()
             packet = wpa2_data.decode(decoded_string)
         else:
@@ -692,32 +672,32 @@ class Dot11WPA2Decoder(BaseDot11Decoder):
             packet = data_decoder.decode(wpa2.body_string)
 
             wpa2.contains(packet)
-            
+
             return wpa2
-        
+
 class Dot11WPA2DataDecoder(BaseDot11Decoder):
     def __init__(self):
         BaseDot11Decoder.__init__(self)
-        
+
     def decode(self, aBuffer):
         wpa2_data = dot11.Dot11WPA2Data(aBuffer)
         self.set_decoded_protocol( wpa2_data )
 
         llc_decoder = LLCDecoder()
         packet = self.llc_decoder.decode(wpa2_data.body_string)
-        
+
         wpa2_data.contains(packet)
-        
+
         return wpa2_data
-    
+
 class LLCDecoder(Decoder):
     def __init__(self):
         pass
-        
+
     def decode(self, aBuffer):
         d = dot11.LLC(aBuffer)
         self.set_decoded_protocol( d )
-        
+
         if d.get_DSAP()==dot11.SAPTypes.SNAP:
             if d.get_SSAP()==dot11.SAPTypes.SNAP:
                 if d.get_control()==dot11.LLC.DLC_UNNUMBERED_FRAMES:
@@ -725,7 +705,7 @@ class LLCDecoder(Decoder):
                     packet = snap_decoder.decode(d.body_string)
                     d.contains(packet)
                     return d
-        
+
         # Only SNAP is implemented
         data_decoder = DataDecoder()
         packet = data_decoder.decode(d.body_string)
@@ -735,7 +715,7 @@ class LLCDecoder(Decoder):
 class SNAPDecoder(Decoder):
     def __init__(self):
         pass
-        
+
     def decode(self, aBuffer):
         s = dot11.SNAP(aBuffer)
         self.set_decoded_protocol( s )
@@ -763,27 +743,27 @@ class SNAPDecoder(Decoder):
         return s
 
 class CDPDecoder(Decoder):
-    
+
     def __init__(self):
         pass
-        
+
     def decode(self, aBuffer):
         s = CDP(aBuffer)
         self.set_decoded_protocol( s )
         return s
-            
+
 class Dot11ManagementDecoder(BaseDot11Decoder):
     def __init__(self):
         BaseDot11Decoder.__init__(self)
         self.subtype = None
-        
+
     def set_subtype(self, subtype):
         self.subtype=subtype
-    
+
     def decode(self, aBuffer):
         p = dot11.Dot11ManagementFrame(aBuffer)
         self.set_decoded_protocol( p )
-        
+
         if self.subtype is dot11.Dot11Types.DOT11_SUBTYPE_MANAGEMENT_BEACON:
             self.mgt_beacon_decoder = Dot11ManagementBeaconDecoder()
             packet = self.mgt_beacon_decoder.decode(p.body_string)
@@ -817,38 +797,38 @@ class Dot11ManagementDecoder(BaseDot11Decoder):
         else:
             data_decoder = DataDecoder()
             packet = data_decoder.decode(p.body_string)
-        
+
         p.contains(packet)
         return p
 
 class Dot11ManagementBeaconDecoder(BaseDot11Decoder):
     def __init__(self):
         BaseDot11Decoder.__init__(self)
-        
+
     def decode(self, aBuffer):
         p = dot11.Dot11ManagementBeacon(aBuffer)
         self.set_decoded_protocol( p )
-        
+
         return p
 
 class Dot11ManagementProbeRequestDecoder(BaseDot11Decoder):
     def __init__(self):
         BaseDot11Decoder.__init__(self)
-        
+
     def decode(self, aBuffer):
         p = dot11.Dot11ManagementProbeRequest(aBuffer)
         self.set_decoded_protocol( p )
-        
+
         return p
 
 class Dot11ManagementProbeResponseDecoder(BaseDot11Decoder):
     def __init__(self):
         BaseDot11Decoder.__init__(self)
-        
+
     def decode(self, aBuffer):
         p = dot11.Dot11ManagementProbeResponse(aBuffer)
         self.set_decoded_protocol( p )
-        
+
         return p
 
 class Dot11ManagementDeauthenticationDecoder(BaseDot11Decoder):
@@ -858,7 +838,7 @@ class Dot11ManagementDeauthenticationDecoder(BaseDot11Decoder):
     def decode(self, aBuffer):
         p = dot11.Dot11ManagementDeauthentication(aBuffer)
         self.set_decoded_protocol( p )
-        
+
         return p
 
 class Dot11ManagementAuthenticationDecoder(BaseDot11Decoder):
@@ -874,57 +854,57 @@ class Dot11ManagementAuthenticationDecoder(BaseDot11Decoder):
 class Dot11ManagementDisassociationDecoder(BaseDot11Decoder):
     def __init__(self):
         BaseDot11Decoder.__init__(self)
-        
+
     def decode(self, aBuffer):
         p = dot11.Dot11ManagementDisassociation(aBuffer)
         self.set_decoded_protocol(p)
-        
+
         return p
 
 class Dot11ManagementAssociationRequestDecoder(BaseDot11Decoder):
     def __init__(self):
         BaseDot11Decoder.__init__(self)
-        
+
     def decode(self, aBuffer):
         p = dot11.Dot11ManagementAssociationRequest(aBuffer)
         self.set_decoded_protocol(p)
-        
+
         return p
 
 class Dot11ManagementAssociationResponseDecoder(BaseDot11Decoder):
     def __init__(self):
         BaseDot11Decoder.__init__(self)
-        
+
     def decode(self, aBuffer):
         p = dot11.Dot11ManagementAssociationResponse(aBuffer)
         self.set_decoded_protocol(p)
-        
+
         return p
 
 class Dot11ManagementReassociationRequestDecoder(BaseDot11Decoder):
     def __init__(self):
         BaseDot11Decoder.__init__(self)
-        
+
     def decode(self, aBuffer):
         p = dot11.Dot11ManagementReassociationRequest(aBuffer)
         self.set_decoded_protocol(p)
-        
+
         return p
 
 class Dot11ManagementReassociationResponseDecoder(BaseDot11Decoder):
     def __init__(self):
         BaseDot11Decoder.__init__(self)
-        
+
     def decode(self, aBuffer):
         p = dot11.Dot11ManagementReassociationResponse(aBuffer)
         self.set_decoded_protocol(p)
-        
+
         return p
 
 class BaseDecoder(Decoder):
-    
+
     def decode(self, buff):
-        
+
         packet = self.klass(buff)
         self.set_decoded_protocol(packet)
         cd = self.child_decoders.get(self.child_key(packet), DataDecoder())
@@ -936,7 +916,7 @@ class SimpleConfigDecoder(BaseDecoder):
     child_decoders = {}
     klass = wps.SimpleConfig
     child_key = lambda s,p: None
-    
+
     def decode(self, buff):
         sc = BaseDecoder.decode(self, buff)
         ary = array.array('B', sc.child().get_packet())
@@ -944,7 +924,7 @@ class SimpleConfigDecoder(BaseDecoder):
         tlv = wps.SimpleConfig.build_tlv_container()
         tlv.from_ary(ary)
         sc.contains(tlv)
-        
+
         return sc
 
 class EAPExpandedDecoder(BaseDecoder):
@@ -953,14 +933,14 @@ class EAPExpandedDecoder(BaseDecoder):
     }
     klass = eap.EAPExpanded
     child_key = lambda s,p: (p.get_vendor_id(), p.get_vendor_type())
-        
+
 class EAPRDecoder(BaseDecoder):
     child_decoders = {
         eap.EAPR.EXPANDED:EAPExpandedDecoder()
     }
     klass = eap.EAPR
     child_key = lambda s, p: p.get_type()
-        
+
 class EAPDecoder(BaseDecoder):
     child_decoders = {
         eap.EAP.REQUEST: EAPRDecoder(),
@@ -968,7 +948,7 @@ class EAPDecoder(BaseDecoder):
     }
     klass = eap.EAP
     child_key = lambda s, p: p.get_code()
-        
+
 class EAPOLDecoder(BaseDecoder):
     child_decoders = {
         eap.EAPOL.EAP_PACKET: EAPDecoder()
