@@ -1,4 +1,4 @@
-# Copyright (c) 2003-2016 CORE Security Technologies
+# SECUREAUTH LABS. Copyright 2018 SecureAuth Corporation. All rights reserved.
 #
 # This software is provided under under a slightly modified version
 # of the Apache Software License. See the accompanying LICENSE file
@@ -7,11 +7,11 @@
 # Author: Alberto Solino (beto@coresecurity.com)
 #
 # Description:
-#   RFC 4493 implementation (http://www.ietf.org/rfc/rfc4493.txt)
-#   RFC 4615 implementation (http://www.ietf.org/rfc/rfc4615.txt)
+#   RFC 4493 implementation (https://www.ietf.org/rfc/rfc4493.txt)
+#   RFC 4615 implementation (https://www.ietf.org/rfc/rfc4615.txt)
 #
 #   NIST SP 800-108 Section 5.1, with PRF HMAC-SHA256 implementation
-#   (http://tools.ietf.org/html/draft-irtf-cfrg-kdf-uses-00#ref-SP800-108)
+#   (https://tools.ietf.org/html/draft-irtf-cfrg-kdf-uses-00#ref-SP800-108)
 #
 #   [MS-LSAD] Section 5.1.2
 #   [MS-SAMR] Section 2.2.11.1.1
@@ -20,10 +20,10 @@ from __future__ import division
 from __future__ import print_function
 from impacket import LOG
 try:
-    from Crypto.Cipher import DES, AES, ARC4
+    from Cryptodome.Cipher import DES, AES, ARC4
 except Exception:
-    LOG.error("Warning: You don't have any crypto installed. You need PyCrypto")
-    LOG.error("See http://www.pycrypto.org/")
+    LOG.error("Warning: You don't have any crypto installed. You need pycryptodomex")
+    LOG.error("See https://pypi.org/project/pycryptodomex/")
 from struct import pack, unpack
 from impacket.structure import Structure
 import hmac, hashlib
@@ -54,7 +54,7 @@ def Generate_Subkey(K):
 #   +                                                                   +
 #   +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 
-    AES_128 = AES.new(K)
+    AES_128 = AES.new(K, AES.MODE_ECB)
 
     L = AES_128.encrypt('\x00'*16)
 
@@ -140,7 +140,7 @@ def AES_CMAC(K, M, length):
     const_Bsize = 16
     const_Zero  = '\x00'*16
 
-    AES_128= AES.new(K)
+    AES_128= AES.new(K, AES.MODE_ECB)
     M      = M[:length]
     K1, K2 = Generate_Subkey(K)
     n      = len(M)//const_Bsize
@@ -200,12 +200,12 @@ def AES_CMAC_PRF_128(VK, M, VKlen, Mlen):
         K = AES_CMAC('\x00'*16, VK, VKlen)
 
     PRV = AES_CMAC(K, M, Mlen)
- 
+
     return PRV
 
 def KDF_CounterMode(KI, Label, Context, L):
 # Implements NIST SP 800-108 Section 5.1, with PRF HMAC-SHA256
-# http://tools.ietf.org/html/draft-irtf-cfrg-kdf-uses-00#ref-SP800-108
+# https://tools.ietf.org/html/draft-irtf-cfrg-kdf-uses-00#ref-SP800-108
 # Fixed values:
 #  1. h - The length of the output of the PRF in bits, and
 #  2. r - The length of the binary representation of the counter i.
@@ -220,7 +220,7 @@ def KDF_CounterMode(KI, Label, Context, L):
 #  5. Return: KO := the leftmost L bits of result(n).
     h = 256
     r = 32
-    
+
     n = L // h
 
     if n == 0:
@@ -234,9 +234,9 @@ def KDF_CounterMode(KI, Label, Context, L):
 
     for i in range(1,n+1):
        input = pack('>L', i) + Label + '\x00' + Context + pack('>L',L)
-       K = hmac.new(KI, input, hashlib.sha256).digest() 
+       K = hmac.new(KI, input, hashlib.sha256).digest()
        result = result + K
- 
+
     return result[:(L//8)]
 
 # [MS-LSAD] Section 5.1.2 / 5.1.3
@@ -274,7 +274,7 @@ def decryptSecret(key, value):
         tmpStrKey = key0[:7]
         tmpKey = transformKey(tmpStrKey)
         Crypt1 = DES.new(tmpKey, DES.MODE_ECB)
-        plainText += Crypt1.decrypt(cipherText) 
+        plainText += Crypt1.decrypt(cipherText)
         cipherText = cipherText[8:]
         key0 = key0[7:]
         value = value[8:]
@@ -298,7 +298,7 @@ def encryptSecret(key, value):
         tmpStrKey = key0[:7]
         tmpKey = transformKey(tmpStrKey)
         Crypt1 = DES.new(tmpKey, DES.MODE_ECB)
-        cipherText += Crypt1.encrypt(plainText) 
+        cipherText += Crypt1.encrypt(plainText)
         plainText = plainText[8:]
         key0 = key0[7:]
         value0 = value0[8:]
@@ -324,7 +324,7 @@ def SamDecryptNTLMHash(encryptedHash, key):
     plain1 = Crypt1.decrypt(Block1)
     plain2 = Crypt2.decrypt(Block2)
 
-    return plain1 + plain2 
+    return plain1 + plain2
 
 def SamEncryptNTLMHash(encryptedHash, key):
     # [MS-SAMR] Section 2.2.11.1.1
@@ -342,7 +342,7 @@ def SamEncryptNTLMHash(encryptedHash, key):
     plain1 = Crypt1.encrypt(Block1)
     plain2 = Crypt2.encrypt(Block2)
 
-    return plain1 + plain2 
+    return plain1 + plain2
 
 
 
@@ -389,7 +389,7 @@ if __name__ == '__main__':
 
         print()
         return ''
-    
+
     from binascii import hexlify, unhexlify
 
     K = "2b7e151628aed2a6abf7158809cf4f3c"
@@ -404,19 +404,19 @@ if __name__ == '__main__':
     print("Example 1: len = 0")
     print("M                <empty string>")
     pp("AES-CMAC        " , (hexlify(AES_CMAC(unhexlify(K),unhexlify(M),0))))
-    print() 
+    print()
     print("Example 2: len = 16")
     pp("M               " , (M[:16*2]))
     pp("AES-CMAC        " , (hexlify(AES_CMAC(unhexlify(K),unhexlify(M),16))))
-    print() 
+    print()
     print("Example 3: len = 40")
     pp("M               " , (M[:40*2]))
     pp("AES-CMAC        " , (hexlify(AES_CMAC(unhexlify(K),unhexlify(M),40))))
-    print() 
+    print()
     print("Example 3: len = 64")
     pp("M               " , (M[:64*2]))
     pp("AES-CMAC        " , (hexlify(AES_CMAC(unhexlify(K),unhexlify(M),64))))
-    print() 
+    print()
     M = "eeab9ac8fb19cb012849536168b5d6c7a5e6c5b2fcdc32bc29b0e3654078a5129f6be2562046766f93eebf146b"
     K = "6c3473624099e17ff3a39ff6bdf6cc38"
     # Mac = dbf63fd93c4296609e2d66bf79251cb5
@@ -453,19 +453,19 @@ if __name__ == '__main__':
     print()
     print("Example 1: len = 0")
     pp("M               " , (K))
-    print("Key Length       18 ")  
+    print("Key Length       18 ")
     pp("AES-CMAC        " , (hexlify(AES_CMAC_PRF_128(unhexlify(K),unhexlify(M),18,len(unhexlify(M))))))
-    print() 
+    print()
     print("Example 1: len = 0")
     pp("M               " , (K))
-    print("Key Length       16 ")  
+    print("Key Length       16 ")
     pp("AES-CMAC        " , (hexlify(AES_CMAC_PRF_128(unhexlify(K)[:16],unhexlify(M),16,len(unhexlify(M))))))
-    print() 
+    print()
     print("Example 1: len = 0")
     pp("M               " , (K))
     print("Key Length       10 ")
     pp("AES-CMAC        " , (hexlify(AES_CMAC_PRF_128(unhexlify(K)[:10],unhexlify(M),10,len(unhexlify(M))))))
-    print() 
+    print()
 
 
 
