@@ -1,4 +1,4 @@
-# Copyright (c) 2003-2016 CORE Security Technologies
+# SECUREAUTH LABS. Copyright 2018 SecureAuth Corporation. All rights reserved.
 #
 # This software is provided under under a slightly modified version
 # of the Apache Software License. See the accompanying LICENSE file
@@ -30,13 +30,19 @@ from impacket.krb5.types import KerberosTime, Principal, Ticket
 from impacket.krb5.gssapi import CheckSumField, GSS_C_DCE_STYLE, GSS_C_MUTUAL_FLAG, GSS_C_REPLAY_FLAG, \
     GSS_C_SEQUENCE_FLAG, GSS_C_CONF_FLAG, GSS_C_INTEG_FLAG
 from impacket.krb5 import constants
-from impacket.krb5.crypto import Key, _enctype_table
+from impacket.krb5.crypto import Key, _enctype_table, InvalidChecksum
 from impacket.smbconnection import SessionError
 from impacket.spnego import SPNEGO_NegTokenInit, TypesMech, SPNEGO_NegTokenResp, ASN1_OID, asn1encode, ASN1_AID
 from impacket.krb5.gssapi import KRB5_AP_REQ
 from impacket import nt_errors, LOG
 from impacket.krb5.ccache import CCache
 
+# Our random number generator
+try:
+    rand = random.SystemRandom()
+except NotImplementedError:
+    rand = random
+    pass
 
 def sendReceive(data, host, kdcHost):
     if kdcHost is None:
@@ -110,7 +116,7 @@ def getKerberosTGT(clientName, password, domain, lmhash, nthash, aesKey='', kdcH
     now = datetime.datetime.utcnow() + datetime.timedelta(days=1)
     reqBody['till'] = KerberosTime.to_asn1(now)
     reqBody['rtime'] = KerberosTime.to_asn1(now)
-    reqBody['nonce'] =  random.getrandbits(31)
+    reqBody['nonce'] =  rand.getrandbits(31)
 
     # Yes.. this shouldn't happen but it's inherited from the past
     if aesKey is None:
@@ -163,15 +169,16 @@ def getKerberosTGT(clientName, password, domain, lmhash, nthash, aesKey='', kdcH
         # Yes
         preAuth = False
 
+    encryptionTypesData = dict()
+    salt = ''
     if preAuth is False:
         # In theory, we should have the right credentials for the etype specified before.
         methods = asRep['padata']
+        encryptionTypesData[supportedCiphers[0]] = salt # handle RC4 fallback, we don't need any salt
         tgt = r
     else:
         methods = decoder.decode(str(asRep['e-data']), asn1Spec=METHOD_DATA())[0]
 
-    salt = ''
-    encryptionTypesData = dict()
     for method in methods:
         if method['padata-type'] == constants.PreAuthenticationDataTypes.PA_ETYPE_INFO2.value:
             etypes2 = decoder.decode(str(method['padata-value']), asn1Spec = ETYPE_INFO2())[0]
@@ -266,7 +273,7 @@ def getKerberosTGT(clientName, password, domain, lmhash, nthash, aesKey='', kdcH
         now = datetime.datetime.utcnow() + datetime.timedelta(days=1)
         reqBody['till'] = KerberosTime.to_asn1(now)
         reqBody['rtime'] =  KerberosTime.to_asn1(now)
-        reqBody['nonce'] = random.getrandbits(31)
+        reqBody['nonce'] = rand.getrandbits(31)
 
         seq_set_iter(reqBody, 'etype', ( (int(cipher.enctype),)))
 
@@ -295,7 +302,14 @@ def getKerberosTGT(clientName, password, domain, lmhash, nthash, aesKey='', kdcH
     # AS-REP encrypted part (includes TGS session key or
     # application session key), encrypted with the client key
     # (Section 5.4.2)
-    plainText = cipher.decrypt(key, 3, str(cipherText))
+    try:
+        plainText = cipher.decrypt(key, 3, str(cipherText))
+    except InvalidChecksum, e:
+        # probably bad password if preauth is disabled
+        if preAuth is False:
+            error_msg = "failed to decrypt session key: %s" % str(e)
+            raise SessionKeyDecryptionError(error_msg, asRep, cipher, key, cipherText)
+        raise
     encASRepPart = decoder.decode(plainText, asn1Spec = EncASRepPart())[0]
 
     # Get the session key and the ticket
@@ -380,7 +394,7 @@ def getKerberosTGS(serverName, domain, kdcHost, tgt, cipher, sessionKey):
     now = datetime.datetime.utcnow() + datetime.timedelta(days=1)
 
     reqBody['till'] = KerberosTime.to_asn1(now)
-    reqBody['nonce'] = random.getrandbits(31)
+    reqBody['nonce'] = rand.getrandbits(31)
     seq_set_iter(reqBody, 'etype',
                       (
                           int(constants.EncryptionTypes.rc4_hmac.value),
@@ -631,6 +645,25 @@ def getKerberosType1(username, password, domain, lmhash, nthash, aesKey='', TGT
 
     return cipher, sessionKey, blob.getData()
 
+
+class SessionKeyDecryptionError(Exception):
+    """
+    Exception risen when we fail to decrypt a session key within an AS-REP
+    message.
+    It provides context information such as full AS-REP message but also the
+    cipher, key and cipherText used when the error occurred.
+    """
+    def __init__( self, message, asRep, cipher, key, cipherText):
+        self.message = message
+        self.asRep = asRep
+        self.cipher = cipher
+        self.key = key
+        self.cipherText = cipherText
+
+    def __str__ ( self):
+        return "SessionKeyDecryptionError: %s" % self.message
+
+
 class KerberosError(SessionError):
     """
     This is the exception every client should catch regardless of the underlying
